API Reference
=============

This page contains the complete API reference for PIICleaner.

Cleaner Class
-------------

.. autoclass:: piicleaner.Cleaner
   :members:
   :undoc-members:
   :show-inheritance:

Core Functions
--------------

These are the low-level functions that power the Cleaner class. You typically don't need to use these directly.

.. automodule:: piicleaner._internal
   :members:
   :undoc-members:

Polars Integration
------------------

.. automodule:: piicleaner._polars
   :members:
   :undoc-members:
   :show-inheritance:

Pandas Integration
------------------

.. automodule:: piicleaner._pandas
   :members:
   :undoc-members:
   :show-inheritance: